Linux frigo.o2switch.net 4.18.0-553.123.2.lve.el8.x86_64 #1 SMP Thu May 7 23:17:13 UTC 2026 x86_64
Apache
: 109.234.164.159 | : 216.73.216.204
Cant Read [ /etc/named.conf ]
8.3.33
lavi4235
www.github.com/MadExploits
Terminal
AUTO ROOT
Adminer
Backdoor Destroyer
Linux Exploit
Lock Shell
Lock File
Create User
CREATE RDP
PHP Mailer
BACKCONNECT
UNLOCK SHELL
HASH IDENTIFIER
CPANEL RESET
CREATE WP USER
README
+ Create Folder
+ Create File
/
usr /
lib64 /
llvm17 /
lib /
clang /
17 /
include /
[ HOME SHELL ]
Name
Size
Permission
Action
cuda_wrappers
[ DIR ]
drwxr-xr-x
llvm_libc_wrappers
[ DIR ]
drwxr-xr-x
openmp_wrappers
[ DIR ]
drwxr-xr-x
ppc_wrappers
[ DIR ]
drwxr-xr-x
__clang_cuda_builtin_vars.h
4.78
KB
-rw-r--r--
__clang_cuda_cmath.h
18.06
KB
-rw-r--r--
__clang_cuda_complex_builtins....
9.36
KB
-rw-r--r--
__clang_cuda_device_functions....
56.68
KB
-rw-r--r--
__clang_cuda_intrinsics.h
29.93
KB
-rw-r--r--
__clang_cuda_libdevice_declare...
21.87
KB
-rw-r--r--
__clang_cuda_math.h
15.99
KB
-rw-r--r--
__clang_cuda_math_forward_decl...
8.27
KB
-rw-r--r--
__clang_cuda_runtime_wrapper.h
17.61
KB
-rw-r--r--
__clang_cuda_texture_intrinsic...
31.86
KB
-rw-r--r--
__clang_hip_cmath.h
26.34
KB
-rw-r--r--
__clang_hip_libdevice_declares...
19.87
KB
-rw-r--r--
__clang_hip_math.h
31.96
KB
-rw-r--r--
__clang_hip_runtime_wrapper.h
4.65
KB
-rw-r--r--
__clang_hip_stdlib.h
1.19
KB
-rw-r--r--
__stddef_max_align_t.h
857
B
-rw-r--r--
__wmmintrin_aes.h
5.15
KB
-rw-r--r--
__wmmintrin_pclmul.h
1.99
KB
-rw-r--r--
adxintrin.h
7.37
KB
-rw-r--r--
altivec.h
697.32
KB
-rw-r--r--
ammintrin.h
7.54
KB
-rw-r--r--
amxcomplexintrin.h
6.81
KB
-rw-r--r--
amxfp16intrin.h
1.82
KB
-rw-r--r--
amxintrin.h
21.12
KB
-rw-r--r--
arm64intr.h
993
B
-rw-r--r--
arm_acle.h
25.66
KB
-rw-r--r--
arm_bf16.h
548
B
-rw-r--r--
arm_cde.h
32.67
KB
-rw-r--r--
arm_cmse.h
6.21
KB
-rw-r--r--
arm_fp16.h
16.92
KB
-rw-r--r--
arm_mve.h
1.48
MB
-rw-r--r--
arm_neon.h
2.45
MB
-rw-r--r--
arm_neon_sve_bridge.h
9.48
KB
-rw-r--r--
arm_sme_draft_spec_subject_to_...
60.2
KB
-rw-r--r--
arm_sve.h
1.51
MB
-rw-r--r--
armintr.h
843
B
-rw-r--r--
avx2intrin.h
186.96
KB
-rw-r--r--
avx512bf16intrin.h
10.51
KB
-rw-r--r--
avx512bitalgintrin.h
2.41
KB
-rw-r--r--
avx512bwintrin.h
75.33
KB
-rw-r--r--
avx512cdintrin.h
4.12
KB
-rw-r--r--
avx512dqintrin.h
58.75
KB
-rw-r--r--
avx512erintrin.h
11.83
KB
-rw-r--r--
avx512fintrin.h
382.64
KB
-rw-r--r--
avx512fp16intrin.h
156.63
KB
-rw-r--r--
avx512ifmaintrin.h
2.49
KB
-rw-r--r--
avx512ifmavlintrin.h
4.31
KB
-rw-r--r--
avx512pfintrin.h
4.53
KB
-rw-r--r--
avx512vbmi2intrin.h
13.17
KB
-rw-r--r--
avx512vbmiintrin.h
3.72
KB
-rw-r--r--
avx512vbmivlintrin.h
6.94
KB
-rw-r--r--
avx512vlbf16intrin.h
19.21
KB
-rw-r--r--
avx512vlbitalgintrin.h
4.23
KB
-rw-r--r--
avx512vlbwintrin.h
121.26
KB
-rw-r--r--
avx512vlcdintrin.h
7.66
KB
-rw-r--r--
avx512vldqintrin.h
46.41
KB
-rw-r--r--
avx512vlfp16intrin.h
85.51
KB
-rw-r--r--
avx512vlintrin.h
322.29
KB
-rw-r--r--
avx512vlvbmi2intrin.h
25.72
KB
-rw-r--r--
avx512vlvnniintrin.h
13.13
KB
-rw-r--r--
avx512vlvp2intersectintrin.h
4.44
KB
-rw-r--r--
avx512vnniintrin.h
4.21
KB
-rw-r--r--
avx512vp2intersectintrin.h
2.9
KB
-rw-r--r--
avx512vpopcntdqintrin.h
2
KB
-rw-r--r--
avx512vpopcntdqvlintrin.h
3.31
KB
-rw-r--r--
avxifmaintrin.h
5.75
KB
-rw-r--r--
avxintrin.h
195.41
KB
-rw-r--r--
avxneconvertintrin.h
14.09
KB
-rw-r--r--
avxvnniint16intrin.h
17.41
KB
-rw-r--r--
avxvnniint8intrin.h
18.67
KB
-rw-r--r--
avxvnniintrin.h
10.44
KB
-rw-r--r--
bmi2intrin.h
7.09
KB
-rw-r--r--
bmiintrin.h
14.12
KB
-rw-r--r--
builtins.h
741
B
-rw-r--r--
cet.h
1.49
KB
-rw-r--r--
cetintrin.h
3.27
KB
-rw-r--r--
cldemoteintrin.h
1.18
KB
-rw-r--r--
clflushoptintrin.h
1.17
KB
-rw-r--r--
clwbintrin.h
1.2
KB
-rw-r--r--
clzerointrin.h
1.19
KB
-rw-r--r--
cmpccxaddintrin.h
2.33
KB
-rw-r--r--
cpuid.h
11.01
KB
-rw-r--r--
crc32intrin.h
3.27
KB
-rw-r--r--
emmintrin.h
192.64
KB
-rw-r--r--
enqcmdintrin.h
2.12
KB
-rw-r--r--
f16cintrin.h
5.39
KB
-rw-r--r--
float.h
5.63
KB
-rw-r--r--
fma4intrin.h
6.82
KB
-rw-r--r--
fmaintrin.h
28.4
KB
-rw-r--r--
fxsrintrin.h
2.82
KB
-rw-r--r--
gfniintrin.h
7.57
KB
-rw-r--r--
hexagon_circ_brev_intrinsics.h
15.59
KB
-rw-r--r--
hexagon_protos.h
374.42
KB
-rw-r--r--
hexagon_types.h
130.33
KB
-rw-r--r--
hresetintrin.h
1.36
KB
-rw-r--r--
htmintrin.h
6.14
KB
-rw-r--r--
htmxlintrin.h
9.01
KB
-rw-r--r--
hvx_hexagon_protos.h
254.26
KB
-rw-r--r--
ia32intrin.h
12.72
KB
-rw-r--r--
immintrin.h
23.57
KB
-rw-r--r--
intrin.h
28.22
KB
-rw-r--r--
inttypes.h
2.26
KB
-rw-r--r--
invpcidintrin.h
764
B
-rw-r--r--
iso646.h
656
B
-rw-r--r--
keylockerintrin.h
17.98
KB
-rw-r--r--
larchintrin.h
7.8
KB
-rw-r--r--
limits.h
3.61
KB
-rw-r--r--
lwpintrin.h
5
KB
-rw-r--r--
lzcntintrin.h
3.18
KB
-rw-r--r--
mm3dnow.h
4.5
KB
-rw-r--r--
mm_malloc.h
1.88
KB
-rw-r--r--
mmintrin.h
55.98
KB
-rw-r--r--
module.modulemap
3.33
KB
-rw-r--r--
movdirintrin.h
1.57
KB
-rw-r--r--
msa.h
25.01
KB
-rw-r--r--
mwaitxintrin.h
2.19
KB
-rw-r--r--
nmmintrin.h
709
B
-rw-r--r--
opencl-c-base.h
30.38
KB
-rw-r--r--
opencl-c.h
874.39
KB
-rw-r--r--
pconfigintrin.h
1.19
KB
-rw-r--r--
pkuintrin.h
934
B
-rw-r--r--
pmmintrin.h
10.5
KB
-rw-r--r--
popcntintrin.h
1.82
KB
-rw-r--r--
prfchiintrin.h
2.02
KB
-rw-r--r--
prfchwintrin.h
2.06
KB
-rw-r--r--
ptwriteintrin.h
1.05
KB
-rw-r--r--
raointintrin.h
6.59
KB
-rw-r--r--
rdpruintrin.h
1.59
KB
-rw-r--r--
rdseedintrin.h
2.85
KB
-rw-r--r--
riscv_ntlh.h
855
B
-rw-r--r--
rtmintrin.h
1.25
KB
-rw-r--r--
s390intrin.h
604
B
-rw-r--r--
serializeintrin.h
881
B
-rw-r--r--
sgxintrin.h
1.77
KB
-rw-r--r--
sha512intrin.h
5.95
KB
-rw-r--r--
shaintrin.h
7.37
KB
-rw-r--r--
sifive_vector.h
522
B
-rw-r--r--
sm3intrin.h
7.29
KB
-rw-r--r--
sm4intrin.h
8.2
KB
-rw-r--r--
smmintrin.h
99.32
KB
-rw-r--r--
stdalign.h
911
B
-rw-r--r--
stdarg.h
1.66
KB
-rw-r--r--
stdatomic.h
8.3
KB
-rw-r--r--
stdbool.h
1.04
KB
-rw-r--r--
stddef.h
4.16
KB
-rw-r--r--
stdint.h
32.49
KB
-rw-r--r--
stdnoreturn.h
1.17
KB
-rw-r--r--
tbmintrin.h
3.15
KB
-rw-r--r--
tgmath.h
29.68
KB
-rw-r--r--
tmmintrin.h
29.51
KB
-rw-r--r--
tsxldtrkintrin.h
1.97
KB
-rw-r--r--
uintrintrin.h
4.96
KB
-rw-r--r--
unwind.h
11.21
KB
-rw-r--r--
vadefs.h
1.39
KB
-rw-r--r--
vaesintrin.h
2.46
KB
-rw-r--r--
varargs.h
477
B
-rw-r--r--
vecintrin.h
360.82
KB
-rw-r--r--
velintrin.h
2.1
KB
-rw-r--r--
velintrin_approx.h
3.54
KB
-rw-r--r--
velintrin_gen.h
69.06
KB
-rw-r--r--
vpclmulqdqintrin.h
1.06
KB
-rw-r--r--
waitpkgintrin.h
1.33
KB
-rw-r--r--
wasm_simd128.h
76.25
KB
-rw-r--r--
wbnoinvdintrin.h
749
B
-rw-r--r--
wmmintrin.h
659
B
-rw-r--r--
x86gprintrin.h
2.32
KB
-rw-r--r--
x86intrin.h
1.81
KB
-rw-r--r--
xmmintrin.h
106.73
KB
-rw-r--r--
xopintrin.h
19.96
KB
-rw-r--r--
xsavecintrin.h
2.51
KB
-rw-r--r--
xsaveintrin.h
1.64
KB
-rw-r--r--
xsaveoptintrin.h
1
KB
-rw-r--r--
xsavesintrin.h
1.24
KB
-rw-r--r--
xtestintrin.h
873
B
-rw-r--r--
Delete
Unzip
Zip
${this.title}
Close
Code Editor : __clang_cuda_math_forward_declares.h
/*===- __clang_math_forward_declares.h - Prototypes of __device__ math fns --=== * * Part of the LLVM Project, under the Apache License v2.0 with LLVM Exceptions. * See https://llvm.org/LICENSE.txt for license information. * SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception * *===-----------------------------------------------------------------------=== */ #ifndef __CLANG__CUDA_MATH_FORWARD_DECLARES_H__ #define __CLANG__CUDA_MATH_FORWARD_DECLARES_H__ #if !defined(__CUDA__) && !__HIP__ #error "This file is for CUDA/HIP compilation only." #endif // This file forward-declares of some math functions we (or the CUDA headers) // will define later. We need to do this, and do it before cmath is included, // because the standard library may have constexpr math functions. In the // absence of a prior __device__ decl, those constexpr functions may become // implicitly host+device. host+device functions can't be overloaded, so that // would preclude the use of our own __device__ overloads for these functions. #pragma push_macro("__DEVICE__") #define __DEVICE__ \ static __inline__ __attribute__((always_inline)) __attribute__((device)) __DEVICE__ long abs(long); __DEVICE__ long long abs(long long); __DEVICE__ double abs(double); __DEVICE__ float abs(float); __DEVICE__ int abs(int); __DEVICE__ double acos(double); __DEVICE__ float acos(float); __DEVICE__ double acosh(double); __DEVICE__ float acosh(float); __DEVICE__ double asin(double); __DEVICE__ float asin(float); __DEVICE__ double asinh(double); __DEVICE__ float asinh(float); __DEVICE__ double atan2(double, double); __DEVICE__ float atan2(float, float); __DEVICE__ double atan(double); __DEVICE__ float atan(float); __DEVICE__ double atanh(double); __DEVICE__ float atanh(float); __DEVICE__ double cbrt(double); __DEVICE__ float cbrt(float); __DEVICE__ double ceil(double); __DEVICE__ float ceil(float); __DEVICE__ double copysign(double, double); __DEVICE__ float copysign(float, float); __DEVICE__ double cos(double); __DEVICE__ float cos(float); __DEVICE__ double cosh(double); __DEVICE__ float cosh(float); __DEVICE__ double erfc(double); __DEVICE__ float erfc(float); __DEVICE__ double erf(double); __DEVICE__ float erf(float); __DEVICE__ double exp2(double); __DEVICE__ float exp2(float); __DEVICE__ double exp(double); __DEVICE__ float exp(float); __DEVICE__ double expm1(double); __DEVICE__ float expm1(float); __DEVICE__ double fabs(double); __DEVICE__ float fabs(float); __DEVICE__ double fdim(double, double); __DEVICE__ float fdim(float, float); __DEVICE__ double floor(double); __DEVICE__ float floor(float); __DEVICE__ double fma(double, double, double); __DEVICE__ float fma(float, float, float); __DEVICE__ double fmax(double, double); __DEVICE__ float fmax(float, float); __DEVICE__ double fmin(double, double); __DEVICE__ float fmin(float, float); __DEVICE__ double fmod(double, double); __DEVICE__ float fmod(float, float); __DEVICE__ int fpclassify(double); __DEVICE__ int fpclassify(float); __DEVICE__ double frexp(double, int *); __DEVICE__ float frexp(float, int *); __DEVICE__ double hypot(double, double); __DEVICE__ float hypot(float, float); __DEVICE__ int ilogb(double); __DEVICE__ int ilogb(float); #ifdef _MSC_VER __DEVICE__ bool isfinite(long double); #endif __DEVICE__ bool isfinite(double); __DEVICE__ bool isfinite(float); __DEVICE__ bool isgreater(double, double); __DEVICE__ bool isgreaterequal(double, double); __DEVICE__ bool isgreaterequal(float, float); __DEVICE__ bool isgreater(float, float); #ifdef _MSC_VER __DEVICE__ bool isinf(long double); #endif __DEVICE__ bool isinf(double); __DEVICE__ bool isinf(float); __DEVICE__ bool isless(double, double); __DEVICE__ bool islessequal(double, double); __DEVICE__ bool islessequal(float, float); __DEVICE__ bool isless(float, float); __DEVICE__ bool islessgreater(double, double); __DEVICE__ bool islessgreater(float, float); #ifdef _MSC_VER __DEVICE__ bool isnan(long double); #endif __DEVICE__ bool isnan(double); __DEVICE__ bool isnan(float); __DEVICE__ bool isnormal(double); __DEVICE__ bool isnormal(float); __DEVICE__ bool isunordered(double, double); __DEVICE__ bool isunordered(float, float); __DEVICE__ long labs(long); __DEVICE__ double ldexp(double, int); __DEVICE__ float ldexp(float, int); __DEVICE__ double lgamma(double); __DEVICE__ float lgamma(float); __DEVICE__ long long llabs(long long); __DEVICE__ long long llrint(double); __DEVICE__ long long llrint(float); __DEVICE__ double log10(double); __DEVICE__ float log10(float); __DEVICE__ double log1p(double); __DEVICE__ float log1p(float); __DEVICE__ double log2(double); __DEVICE__ float log2(float); __DEVICE__ double logb(double); __DEVICE__ float logb(float); __DEVICE__ double log(double); __DEVICE__ float log(float); __DEVICE__ long lrint(double); __DEVICE__ long lrint(float); __DEVICE__ long lround(double); __DEVICE__ long lround(float); __DEVICE__ long long llround(float); // No llround(double). __DEVICE__ double modf(double, double *); __DEVICE__ float modf(float, float *); __DEVICE__ double nan(const char *); __DEVICE__ float nanf(const char *); __DEVICE__ double nearbyint(double); __DEVICE__ float nearbyint(float); __DEVICE__ double nextafter(double, double); __DEVICE__ float nextafter(float, float); __DEVICE__ double pow(double, double); __DEVICE__ double pow(double, int); __DEVICE__ float pow(float, float); __DEVICE__ float pow(float, int); __DEVICE__ double remainder(double, double); __DEVICE__ float remainder(float, float); __DEVICE__ double remquo(double, double, int *); __DEVICE__ float remquo(float, float, int *); __DEVICE__ double rint(double); __DEVICE__ float rint(float); __DEVICE__ double round(double); __DEVICE__ float round(float); __DEVICE__ double scalbln(double, long); __DEVICE__ float scalbln(float, long); __DEVICE__ double scalbn(double, int); __DEVICE__ float scalbn(float, int); #ifdef _MSC_VER __DEVICE__ bool signbit(long double); #endif __DEVICE__ bool signbit(double); __DEVICE__ bool signbit(float); __DEVICE__ double sin(double); __DEVICE__ float sin(float); __DEVICE__ double sinh(double); __DEVICE__ float sinh(float); __DEVICE__ double sqrt(double); __DEVICE__ float sqrt(float); __DEVICE__ double tan(double); __DEVICE__ float tan(float); __DEVICE__ double tanh(double); __DEVICE__ float tanh(float); __DEVICE__ double tgamma(double); __DEVICE__ float tgamma(float); __DEVICE__ double trunc(double); __DEVICE__ float trunc(float); // Notably missing above is nexttoward, which we don't define on // the device side because libdevice doesn't give us an implementation, and we // don't want to be in the business of writing one ourselves. // We need to define these overloads in exactly the namespace our standard // library uses (including the right inline namespace), otherwise they won't be // picked up by other functions in the standard library (e.g. functions in // <complex>). Thus the ugliness below. #ifdef _LIBCPP_BEGIN_NAMESPACE_STD _LIBCPP_BEGIN_NAMESPACE_STD #else namespace std { #ifdef _GLIBCXX_BEGIN_NAMESPACE_VERSION _GLIBCXX_BEGIN_NAMESPACE_VERSION #endif #endif using ::abs; using ::acos; using ::acosh; using ::asin; using ::asinh; using ::atan; using ::atan2; using ::atanh; using ::cbrt; using ::ceil; using ::copysign; using ::cos; using ::cosh; using ::erf; using ::erfc; using ::exp; using ::exp2; using ::expm1; using ::fabs; using ::fdim; using ::floor; using ::fma; using ::fmax; using ::fmin; using ::fmod; using ::fpclassify; using ::frexp; using ::hypot; using ::ilogb; using ::isfinite; using ::isgreater; using ::isgreaterequal; using ::isinf; using ::isless; using ::islessequal; using ::islessgreater; using ::isnan; using ::isnormal; using ::isunordered; using ::labs; using ::ldexp; using ::lgamma; using ::llabs; using ::llrint; using ::log; using ::log10; using ::log1p; using ::log2; using ::logb; using ::lrint; using ::lround; using ::llround; using ::modf; using ::nan; using ::nanf; using ::nearbyint; using ::nextafter; using ::pow; using ::remainder; using ::remquo; using ::rint; using ::round; using ::scalbln; using ::scalbn; using ::signbit; using ::sin; using ::sinh; using ::sqrt; using ::tan; using ::tanh; using ::tgamma; using ::trunc; #ifdef _LIBCPP_END_NAMESPACE_STD _LIBCPP_END_NAMESPACE_STD #else #ifdef _GLIBCXX_BEGIN_NAMESPACE_VERSION _GLIBCXX_END_NAMESPACE_VERSION #endif } // namespace std #endif #pragma pop_macro("__DEVICE__") #endif
Close